@@ -1,3 +1,4 @@
+import asyncio
 import random
 import time
 from concurrent.futures import ThreadPoolExecutor
@@ -175,7 +176,7 @@ class ProxyManager:
         if wait:
             return task.get()
 
-    def start(self):
+    async def start(self):
         self._pool.start()
 
         def fn():
@@ -193,8 +194,9 @@ class ProxyManager:
         for _ in range(self._executor_workers):
             self._executor.submit(fn)
 
-    def stop(self):
-        self._executor_queue.join()
+    async def stop(self, gracefully=True):
+        if gracefully:
+            self._executor_queue.join()
 
         self._executor_running = False
         self._executor.shutdown(True)
@@ -202,18 +204,21 @@ class ProxyManager:
         self._pool.end()
 
     def __enter__(self):
-        self.start()
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(self.start())
 
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.stop()
+        loop = asyncio.get_event_loop()
+        return loop.run_until_complete(self.stop(False))
 
     async def __aenter__(self):
-        return self.__enter__()
+        await self.start()
+        return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        self.__exit__(exc_type, exc_val, exc_tb)
+        return await self.stop(False)
 
 
 class SessionProxy(Session):
